aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorHaacked <haacked@gmail.com>2012-01-12 08:20:25 -0800
committerHaacked <haacked@gmail.com>2012-01-12 08:20:25 -0800
commitbf8a540e757b7f9d0c839e6d9315964c20fc449f (patch)
treed7e02600e707049a3d86d45a357155108a3d8644
parentba1bba11d6ee40854ddddf13c63f58e93a6597dc (diff)
downloadimpress.js-bf8a540e757b7f9d0c839e6d9315964c20fc449f.tar.gz
Updated select method to not run transitions if the element is already active
-rw-r--r--js/impress.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/js/impress.js b/js/impress.js
index dfbaaef..3e6a8d4 100644
--- a/js/impress.js
+++ b/js/impress.js
@@ -187,8 +187,8 @@
var active = null;
var select = function ( el ) {
- if ( !el || !el.stepData ) {
- // selected element is not defined as step
+ if ( !el || !el.stepData || el == active) {
+ // selected element is not defined as step or is already active
return false;
}